@@ -3,12 +3,13 @@ Main interface for transfer service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.transfer import (
+    from mypy_boto3_transfer import (
         Client,
         ListServersPaginator,
         TransferClient,
-        )
+    )
 
     session = boto3.Session()
 
@@ -16,6 +17,7 @@ Usage::
     session_client: TransferClient = session.client("transfer")
 
     list_servers_paginator: ListServersPaginator = client.get_paginator("list_servers")
+    ```
 """
 from mypy_boto3_transfer.client import TransferClient, TransferClient as Client
 from mypy_boto3_transfer.paginator import ListServersPaginator
