@@ -3,14 +3,18 @@ Main interface for transfer service client paginators.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.transfer import (
+
+    from mypy_boto3_transfer import TransferClient
+    from mypy_boto3_transfer import (
         ListServersPaginator,
     )
 
     client: TransferClient = boto3.client("transfer")
 
     list_servers_paginator: ListServersPaginator = client.get_paginator("list_servers")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from typing import Iterator, TYPE_CHECKING
@@ -23,12 +27,12 @@ __all__ = ("ListServersPaginator",)
 
 class ListServersPaginator(Boto3Paginator):
     """
-    [Paginator.ListServers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/transfer.html#Transfer.Paginator.ListServers)
+    [Paginator.ListServers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/transfer.html#Transfer.Paginator.ListServers)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListServersResponseTypeDef]:
         """
-        [ListServers.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/transfer.html#Transfer.Paginator.ListServers.paginate)
+        [ListServers.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/transfer.html#Transfer.Paginator.ListServers.paginate)
         """
